@@ -3,18 +3,8 @@ package Games::Solitaire::Verify::Column;
 use warnings;
 use strict;
 
-=head1 NAME
 
-Games::Solitaire::Verify::Column - a class wrapper for Solitaire
-columns that are composed of a sequence of cards.
-
-=head1 VERSION
-
-Version 0.0101
-
-=cut
-
-our $VERSION = '0.1300';
+our $VERSION = '0.1400';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -26,25 +16,6 @@ __PACKAGE__->mk_acc_ref([qw(
     _s
     )]);
 
-=head1 SYNOPSIS
-
-    use Games::Solitaire::Verify::Column;
-
-    # Initialise a column
-    my $column = Games::Solitaire::Verify::Column->new(
-        {
-            string => ": KH QS 5C",
-        },
-    );
-
-    # Prints 3
-    print $column->len();
-
-    my $queen_card = $column->pos(1);
-
-=head1 FUNCTIONS
-
-=cut
 
 sub _from_string
 {
@@ -98,11 +69,6 @@ sub _init
     }
 }
 
-=head2 $column->len()
-
-Returns an integer representing the number of cards in the column.
-
-=cut
 
 sub len
 {
@@ -111,12 +77,6 @@ sub len
     return scalar(@{$self->_cards()});
 }
 
-=head2 $column->pos($idx)
-
-Returns the card (a L<Games::Solitaire::Verify::Card> object)
-at position $idx in Column. $idx starts at 0.
-
-=cut
 
 sub pos
 {
@@ -126,11 +86,6 @@ sub pos
     return $self->_cards->[$idx];
 }
 
-=head2 $column->top()
-
-Returns the top card.
-
-=cut
 
 sub top
 {
@@ -139,11 +94,6 @@ sub top
     return $self->pos(-1);
 }
 
-=head2 $column->clone()
-
-Returns a clone of the column.
-
-=cut
 
 sub clone
 {
@@ -158,11 +108,6 @@ sub clone
     return $new_col;
 }
 
-=head2 $base_column->append($column_with_more_cards)
-
-Appends the column $column_with_more_cards to $base_column .
-
-=cut
 
 sub append
 {
@@ -177,11 +122,6 @@ sub append
     return;
 }
 
-=head2 $column->push($card)
-
-Appends a single card to the top of the column.
-
-=cut
 
 sub push
 {
@@ -194,11 +134,6 @@ sub push
     return;
 }
 
-=head2 my $card_at_top = $column->pop()
-
-Pops a card from the top of the column and returns it.
-
-=cut
 
 sub pop
 {
@@ -211,22 +146,19 @@ sub pop
     return $card;
 }
 
-=head2 $column->to_string()
-
-Converts to a string.
-
-=cut
 
 sub _recalc
 {
     my $self = shift;
 
+    # We need the single trailing space in an empty line ': ' for
+    # Freecell Solver compatibility
     $self->_s(
-        ":" .
-        ($self->len()
-            ? $self->_non_zero_cards_string()
-            : " " # We need the single trailing space for
-                  # Freecell Solver compatibility
+        ': ' . join(' ',
+            (map
+                { $_->fast_s() }
+                @{$self->_cards()}
+            )
         )
     );
 
@@ -238,68 +170,209 @@ sub to_string
     return shift->_s;
 }
 
-sub _non_zero_cards_string
-{
-    my $self = shift;
+1; # End of Games::Solitaire::Verify::Column
 
-    return join("",
-            (map
-                { " " . $_->fast_s() }
-                @{$self->_cards()}
-            )
-        );
-}
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Games::Solitaire::Verify::Column - a class wrapper for Solitaire
+columns that are composed of a sequence of cards.
+
+=head1 VERSION
+
+version 0.1400
+
+=head1 SYNOPSIS
+
+    use Games::Solitaire::Verify::Column;
+
+    # Initialise a column
+    my $column = Games::Solitaire::Verify::Column->new(
+        {
+            string => ": KH QS 5C",
+        },
+    );
+
+    # Prints 3
+    print $column->len();
+
+    my $queen_card = $column->pos(1);
+
+=head1 METHODS
+
+=head2 $column->len()
+
+Returns an integer representing the number of cards in the column.
+
+=head2 $column->pos($idx)
+
+Returns the card (a L<Games::Solitaire::Verify::Card> object)
+at position $idx in Column. $idx starts at 0.
+
+=head2 $column->top()
+
+Returns the top card.
+
+=head2 $column->clone()
+
+Returns a clone of the column.
+
+=head2 $base_column->append($column_with_more_cards)
+
+Appends the column $column_with_more_cards to $base_column .
+
+=head2 $column->push($card)
+
+Appends a single card to the top of the column.
+
+=head2 my $card_at_top = $column->pop()
+
+Pops a card from the top of the column and returns it.
+
+=head2 $column->to_string()
+
+Converts to a string.
 
 =head1 AUTHOR
 
-Shlomi Fish, L<http://www.shlomifish.org/>.
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-games-solitaire-verifysolution-move at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-Solitaire-Verify>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify or by email
+to bug-games-solitaire-verify@rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
+=head2 Perldoc
+
 You can find documentation for this module with the perldoc command.
 
-    perldoc Games::Solitaire::Verify::Column
+  perldoc Games::Solitaire::Verify
 
+=head2 Websites
 
-You can also look for information at:
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item *
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify>
+MetaCPAN
 
-=item * AnnoCPAN: Annotated CPAN documentation
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://annocpan.org/dist/Games-Solitaire-Verify>
+L<http://metacpan.org/release/Games-Solitaire-Verify>
 
-=item * CPAN Ratings
+=item *
 
-L<http://cpanratings.perl.org/d/Games-Solitaire-Verify>
+Search CPAN
 
-=item * Search CPAN
+The default CPAN search engine, useful to view POD in HTML format.
 
 L<http://search.cpan.org/dist/Games-Solitaire-Verify>
 
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Games-Solitaire-Verify>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Games-Solitaire-Verify>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/Games-Solitaire-Verify>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.perl.org/dist/overview/Games-Solitaire-Verify>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/G/Games-Solitaire-Verify>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Games-Solitaire-Verify>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Games::Solitaire::Verify>
+
 =back
 
+=head2 Bugs / Feature Requests
 
-=head1 ACKNOWLEDGEMENTS
+Please report any bugs or feature requests by email to C<bug-games-solitaire-verify at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-Solitaire-Verify>. You will be automatically notified of any
+progress on the request by the system.
 
+=head2 Source Code
 
-=head1 COPYRIGHT & LICENSE
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
 
-Copyright 2008 Shlomi Fish.
+L<http://bitbucket.org/shlomif/fc-solve>
 
-This program is released under the following license: MIT/X11
-( L<http://www.opensource.org/licenses/mit-license.php> ).
+  git clone http://bitbucket.org/shlomif/fc-solve
 
 =cut
-
-1; # End of Games::Solitaire::Verify::Move
