@@ -3,18 +3,8 @@ package Games::Solitaire::Verify::Freecells;
 use warnings;
 use strict;
 
-=head1 NAME
 
-Games::Solitaire::Verify::Freecells - a class for representing the
-Freecells in games such as Freecell, Baker's Game, or Seahaven Towers
-
-=head1 VERSION
-
-Version 0.01
-
-=cut
-
-our $VERSION = '0.1300';
+our $VERSION = '0.1400';
 
 use parent 'Games::Solitaire::Verify::Base';
 
@@ -28,15 +18,6 @@ __PACKAGE__->mk_acc_ref([qw(
     _cells
     )]);
 
-=head1 SYNOPSIS
-
-    use Games::Solitaire::Verify::Freecells;
-
-    # For internal use.
-
-=head1 FUNCTIONS
-
-=cut
 
 sub _input_from_string
 {
@@ -103,11 +84,6 @@ sub _parse_freecell_card
     );
 }
 
-=head2 $self->count()
-
-Returns the number of cells.
-
-=cut
 
 sub count
 {
@@ -116,11 +92,6 @@ sub count
     return $self->_count();
 }
 
-=head2 $self->cell($index)
-
-Returns the card in the freecell with the index $index .
-
-=cut
 
 sub cell
 {
@@ -129,12 +100,6 @@ sub cell
     return $self->_cells()->[$idx];
 }
 
-=head2 $self->assign($index, $card)
-
-Sets the card in the freecell with the index $index to $card, which
-should be a L<Games::Solitaire::Verify::Card> object.
-
-=cut
 
 sub assign
 {
@@ -145,11 +110,6 @@ sub assign
     return;
 }
 
-=head2 $self->to_string()
-
-Stringifies the freecells into the Freecell Solver solution display notation.
-
-=cut
 
 sub to_string
 {
@@ -163,11 +123,6 @@ sub to_string
     ));
 }
 
-=head2 $self->cell_clone($pos)
-
-Returns a B<clone> of the card in the position $pos .
-
-=cut
 
 sub cell_clone
 {
@@ -178,11 +133,6 @@ sub cell_clone
     return defined($card) ? $card->clone() : undef();
 }
 
-=head2 $self->clear($pos)
-
-Clears/empties the freecell at position $pos .
-
-=cut
 
 sub clear
 {
@@ -193,11 +143,6 @@ sub clear
     return;
 }
 
-=head2 $board->clone()
-
-Returns a clone of the freecells, with all of their cards duplicated.
-
-=cut
 
 
 sub clone
@@ -219,11 +164,6 @@ sub clone
     return $copy;
 }
 
-=head2 $self->num_empty()
-
-Returns the number of empty freecells.
-
-=cut
 
 sub num_empty
 {
@@ -241,55 +181,199 @@ sub num_empty
     return $count;
 }
 
+1; # End of Games::Solitaire::Verify::Freecells
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Games::Solitaire::Verify::Freecells - a class for representing the
+Freecells in games such as Freecell, Baker's Game, or Seahaven Towers
+
+=head1 VERSION
+
+version 0.1400
+
+=head1 SYNOPSIS
+
+    use Games::Solitaire::Verify::Freecells;
+
+    # For internal use.
+
+=head1 METHODS
+
+=head2 $self->count()
+
+Returns the number of cells.
+
+=head2 $self->cell($index)
+
+Returns the card in the freecell with the index $index .
+
+=head2 $self->assign($index, $card)
+
+Sets the card in the freecell with the index $index to $card, which
+should be a L<Games::Solitaire::Verify::Card> object.
+
+=head2 $self->to_string()
+
+Stringifies the freecells into the Freecell Solver solution display notation.
+
+=head2 $self->cell_clone($pos)
+
+Returns a B<clone> of the card in the position $pos .
+
+=head2 $self->clear($pos)
+
+Clears/empties the freecell at position $pos .
+
+=head2 $board->clone()
+
+Returns a clone of the freecells, with all of their cards duplicated.
+
+=head2 $self->num_empty()
+
+Returns the number of empty freecells.
+
 =head1 AUTHOR
 
-Shlomi Fish, L<http://www.shlomifish.org/>.
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-games-solitaire-verifysolution-move at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-Solitaire-Verify>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify or by email
+to bug-games-solitaire-verify@rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
+=head2 Perldoc
+
 You can find documentation for this module with the perldoc command.
 
-    perldoc Games::Solitaire::Verify::Column
+  perldoc Games::Solitaire::Verify
 
-You can also look for information at:
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item *
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify>
+MetaCPAN
 
-=item * AnnoCPAN: Annotated CPAN documentation
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://annocpan.org/dist/Games-Solitaire-Verify>
+L<http://metacpan.org/release/Games-Solitaire-Verify>
 
-=item * CPAN Ratings
+=item *
 
-L<http://cpanratings.perl.org/d/Games-Solitaire-Verify>
+Search CPAN
 
-=item * Search CPAN
+The default CPAN search engine, useful to view POD in HTML format.
 
 L<http://search.cpan.org/dist/Games-Solitaire-Verify>
 
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Games-Solitaire-Verify>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Games-Solitaire-Verify>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Games-Solitaire-Verify>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/Games-Solitaire-Verify>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.perl.org/dist/overview/Games-Solitaire-Verify>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/G/Games-Solitaire-Verify>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Games-Solitaire-Verify>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Games::Solitaire::Verify>
+
 =back
 
+=head2 Bugs / Feature Requests
 
-=head1 ACKNOWLEDGEMENTS
+Please report any bugs or feature requests by email to C<bug-games-solitaire-verify at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-Solitaire-Verify>. You will be automatically notified of any
+progress on the request by the system.
 
+=head2 Source Code
 
-=head1 COPYRIGHT & LICENSE
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
 
-Copyright 2008 Shlomi Fish.
+L<http://bitbucket.org/shlomif/fc-solve>
 
-This program is released under the following license: MIT/X11
-( L<http://www.opensource.org/licenses/mit-license.php> ).
+  git clone http://bitbucket.org/shlomif/fc-solve
 
 =cut
-
-1; # End of Games::Solitaire::Verify::Move
